@@ -51,6 +51,26 @@ ags_live_vst3_bridge_parent_set_callback(GtkWidget *widget, GtkWidget *old_paren
   g_free(str);
 }
 
+void
+ags_live_vst3_bridge_show_gui_callback(GtkMenuItem *item, AgsLiveVst3Bridge *live_vst3_bridge)
+{
+  AgsVst3Plugin *vst3_plugin;
+
+  vst3_plugin = live_vst3_bridge->vst3_plugin;
+
+  if(live_vst3_bridge->iplug_view == NULL){
+    g_message("create view");
+    
+    live_vst3_bridge->iplug_view = ags_vst_iedit_controller_create_view(live_vst3_bridge->iedit_controller,
+									"editor");
+    ags_vst_iplug_view_attached(live_vst3_bridge->iplug_view,
+				gtk_widget_get_toplevel(live_vst3_bridge),
+				"X11EmbedWindowID");
+  }
+  
+  //TODO:JK: implement me
+}
+
 void
 ags_live_vst3_bridge_program_changed_callback(GtkComboBox *combo_box, AgsLiveVst3Bridge *live_vst3_bridge)
 {
